@@ -1,11 +1,11 @@
 ### This is a python package used for configuring a Morpheus appliance ###
 
-from .infra import (
-   infraGroup
+from .infra.groups import (
+   *
 )
 
 from .appliance import (
-   morpheusAppliance
+   appliance
 )
 
 # from .configs import (
